<?php
namespace Ak\Events;

use Laminas\EventManager\EventManager;
use Laminas\EventManager\EventManagerInterface;
use Laminas\EventManager\SharedEventManager;
use Laminas\EventManager\SharedEventManagerInterface;
use Laminas\ServiceManager\Factory\InvokableFactory;

/**
 * Pruža konfiguraciju komponente.
 *
 * @package Ak\Events
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/events
 */
final class ConfigProvider
{
    /**
     * Vraća konfiguraciju.
     *
     * @return array
     */
    public function __invoke(): array
    {
        return [
            'dependencies' => $this->getDependencies(),
        ];
    }

    /**
     * Vraća konfiguraciju containera.
     *
     * @return array
     */
    public function getDependencies(): array
    {
        return [
            'aliases' => [
                'EventManager'                     => EventManager::class,
                EventManagerInterface::class       => EventManager::class,
                'SharedEventManager'               => SharedEventManager::class,
                SharedEventManagerInterface::class => SharedEventManager::class,
            ],

            'factories' => [
                EventManager::class       => EventManagerFactory::class,
                SharedEventManager::class => InvokableFactory::class
            ],

            'shared' => [
                'EventManager'               => false,
                EventManagerInterface::class => false,
                EventManager::class          => false,
            ],
        ];
    }
}
